==> nbdkit_1.42.9.orig.tar.gz: nbdkit-1.42.9/tests/test-time-limit.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright Red Hat
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

# Test nbdkit-time-limit-filter.

source ./functions.sh
set -x

requires_run
requires_plugin null
requires_nbdinfo
requires_nbdsh_uri

# Test ordinary connection with the default (60s) timeout.
nbdkit --filter=time-limit null --run 'nbdinfo "$uri"'

nbdkit -v --filter=time-limit null size=4096 time-limit=10 \
       --run 'nbdsh -u "$uri" -c -' <<'EOF'
import time

# These should succeed.
data = h.pread(512, 0)
data = h.pread(512, 512)
time.sleep(1)
data = h.pread(1024, 512)

# This should fail.
time.sleep(10)
try:
    data = h.pread(2048, 512)
    assert False
except Exception as ex:
    print("error (expected) = %r" % ex)

EOF

==> nbdkit-1.46.0.tar.gz: nbdkit-1.46.0/tests/test-time-limit.sh <==
#!/usr/bin/env bash
# nbdkit
# Copyright Red Hat
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are
# met:
#
# * Redistributions of source code must retain the above copyright
# notice, this list of conditions and the following disclaimer.
#
# * Redistributions in binary form must reproduce the above copyright
# notice, this list of conditions and the following disclaimer in the
# documentation and/or other materials provided with the distribution.
#
# * Neither the name of Red Hat nor the names of its contributors may be
# used to endorse or promote products derived from this software without
# specific prior written permission.
#
# THIS SOFTWARE IS PROVIDED BY RED HAT AND CONTRIBUTORS ''AS IS'' AND
# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
# THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
# PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL RED HAT OR
# CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
# SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
# LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
# USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
# OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
# OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
# SUCH DAMAGE.

# Test nbdkit-time-limit-filter.

source ./functions.sh
#set -e
set -x
set -u

requires_run
requires_plugin null
requires_nbdinfo
requires_nbdsh_uri

# Test ordinary connection with the default (60s) timeout.
nbdkit --filter=time-limit null --run 'nbdinfo "$uri"'

define script <<'EOF'
import time

# These should succeed.
data = h.pread(512, 0)
data = h.pread(512, 512)
time.sleep(1)
data = h.pread(1024, 512)

# This should fail.
time.sleep(10)
try:
    data = h.pread(2048, 512)
    assert False
except Exception as ex:
    print("error (expected) = %r" % ex)
EOF
export script

nbdkit -v --filter=time-limit null size=4096 time-limit=10 \
       --run ' nbdsh -u "$uri" -c "$script" '
